Learn R Programming

hwep (version 2.0.3)

hwenodr: Test for HWE in autopolyploids under the assumption of no double reduction

Description

We run a likelihood ratio test against the null of no HWE, assuming that there is no double reduction.

Usage

hwenodr(nvec)

Value

A list with some or all of the following elements

r

The estimated allele frequency.

chisq_hwe

The chi-square statistic against the null of equilibrium given no double reduction.

df_hwe

The degrees of freedom associated with chisq_hwe.

p_hwe

The p-value against the null of equilibrium given no double reduction.

Arguments

nvec

A vector containing the observed genotype counts, where nvec[[i]] is the number of individuals with genotype i-1. This should be of length ploidy+1.

Author

David Gerard

Examples

Run this code
set.seed(10)
qvec <- c(0.2, 0.3, 0.4, 0.1)
nvec <- c(stats::rmultinom(n = 1, size = 100, prob = qvec))
hwenodr(nvec = nvec)

Run the code above in your browser using DataLab