Learn R Programming

hwep (version 2.0.3)

zygdist: Zygote dosage probabilities.

Description

Calculates the distribution of an offspring dosages given parental dosages (G1 and G2), the ploidy of the species (ploidy), and the double reduction parameter (alpha).

Usage

zygdist(alpha, G1, G2, ploidy)

Value

A vector of probabilities. The ith element is the probability that the offspring will have dosage i-1.

Arguments

alpha

A numeric vector containing the double reduction parameter(s). This should be a vector of length floor(ploidy/4) where alpha[i] is the probability of exactly i pairs of IBDR alleles being in the gamete. Note that sum(alpha) should be less than 1, as 1 - sum(alpha) is the probability of no double reduction.

G1

The dosage of parent 1. Should be an integer between 0 and ploidy.

G2

The dosage of parent 2. Should be an integer between 0 and ploidy.

ploidy

The ploidy of the species. This should be an even positive integer.

Author

David Gerard

Examples

Run this code
zygdist(alpha = c(0.5, 0.1), G1 = 4, G2 = 5, ploidy = 8)

Run the code above in your browser using DataLab