Learn R Programming

hwep (version 2.0.3)

gsegmat: Segregation probabilities of gametes

Description

Produces the segregation probabilities for gamete dosages given parental dosages and the double reduction rate.

Usage

gsegmat(alpha, ploidy)

Value

A matrix of dimension ploidy + 1 by ploidy / 2 + 1. Element (i, j) is the probability that a parent carrying dosage j - 1 produces a gamete with dosage i - 1.

Arguments

alpha

A numeric vector containing the double reduction parameter(s). This should be a vector of length floor(ploidy/4) where alpha[i] is the probability of exactly i pairs of IBDR alleles being in the gamete. Note that sum(alpha) should be less than 1, as 1 - sum(alpha) is the probability of no double reduction.

ploidy

The ploidy of the species. This should be an even positive integer.

Author

David Gerard

Examples

Run this code
gsegmat(alpha = NULL, ploidy = 2)

gsegmat(alpha = 1/6, ploidy = 4)

gsegmat(alpha = 0.3, ploidy = 6)

gsegmat(alpha = c(0.35, 0.02), ploidy = 8)

gsegmat(alpha = c(0.4, 0.05), ploidy = 10)

Run the code above in your browser using DataLab